You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ro...@apache.org on 2009/03/17 15:01:24 UTC

svn commit: r755256 - /qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java

Author: robbie
Date: Tue Mar 17 14:01:23 2009
New Revision: 755256

URL: http://svn.apache.org/viewvc?rev=755256&view=rev
Log:
QPID-1743: change maxMessageSize description to indicate it is in Bytes not KBytes, make size descriptions in other methods consistent

Modified:
    qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java

Modified: qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java?rev=755256&r1=755255&r2=755256&view=diff
==============================================================================
--- qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java (original)
+++ qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java Tue Mar 17 14:01:23 2009
@@ -131,7 +131,7 @@
     void setMaximumMessageAge(Long age) throws IOException;
 
     /**
      * Returns the maximum size of a message (in kbytes) allowed to be accepted by the
      * ManagedQueue. This is useful in setting notifications or taking
      * appropriate action, if the size of the message received is more than
      * the allowed size.
@@ -142,12 +142,12 @@
     Long getMaximumMessageSize() throws IOException;
 
     /**
      * Sets the maximum size of the message (in kbytes) that is allowed to be
      * accepted by the Queue.
      * @param size  maximum size of message.
      * @throws IOException
      */
-    @MBeanAttribute(name="MaximumMessageSize", description="Threshold high value(KB) for a message size")
+    @MBeanAttribute(name="MaximumMessageSize", description="Threshold high value(Bytes) for a message size")
     void setMaximumMessageSize(Long size) throws IOException;
 
     /**
@@ -184,7 +184,6 @@
     @MBeanAttribute(name="MaximumQueueDepth", description="The threshold high value(Bytes) for Queue Depth")
     void setMaximumQueueDepth(Long value) throws IOException;
 
-                                             //TODO change descriptions
     /**
      * View the limit on the memory that this queue will utilise.
      *
@@ -201,7 +200,7 @@
      *
      * @param maximumMemoryUsage The new maximum memory(B) to be used by this queue
      */
-    @MBeanAttribute(name="MemoryUsageMaximum", description="The maximum memory(B) that the queue will occupy.")
+    @MBeanAttribute(name="MemoryUsageMaximum", description="The maximum memory(Bytes) that the queue will occupy.")
     public void setMemoryUsageMaximum(Long maximumMemoryUsage);
 
     /**
@@ -220,7 +219,7 @@
      *
      * @param minimumMemoryUsage The new minimum memory(B) level to be used by this queue
      */
-    @MBeanAttribute(name="MemoryUsageMinimum", description="The minimum memory(B) that the queue will occupy.")
+    @MBeanAttribute(name="MemoryUsageMinimum", description="The minimum memory(Bytes) that the queue will occupy.")
     public void setMemoryUsageMinimum(Long minimumMemoryUsage);
 
     /**
@@ -228,7 +227,7 @@
      *
      * @return The current memory(B) usage of this queue.
      */
-    @MBeanAttribute(name="MemoryUsageCurrent", description="The current amount of memory(B) used by this queue.")
+    @MBeanAttribute(name="MemoryUsageCurrent", description="The current amount of memory(Bytes) used by this queue.")
     public Long getMemoryUsageCurrent();
 
     /**



---------------------------------------------------------------------
@@ -131,7 +131,7 @@
 
     /**
-     * Returns the maximum size of a message (in kbytes) allowed to be accepted by the
+     * Returns the maximum size of a message (in Bytes) allowed to be accepted by the
      * ManagedQueue. This is useful in setting notifications or taking
      * appropriate action, if the size of the message received is more than
@@ -142,12 +142,12 @@
 
     /**
-     * Sets the maximum size of the message (in kbytes) that is allowed to be
+     * Sets the maximum size of the message (in Bytes) that is allowed to be
      * accepted by the Queue.
      * @param size  maximum size of message.
Apache Qpid - AMQP Messaging Implementation
Project:      http://qpid.apache.org
Use/Interact: mailto:commits-subscribe@qpid.apache.org